BiModel class
Constructors
- BiModel({required String nomeCompleto, required String numeroBilhete, required DateTime? dataNascimento, required Sexo sexo, required String estadoCivil, required String residencia, required String naturalDe, required String provinciaDe, required DateTime? emitidoEm, required DateTime? validoAte, required double? altura})
-
BiModel.fromJson(Map<
String, dynamic> json) -
factory
Properties
- altura → double?
-
final
- dataNascimento → DateTime?
-
final
- emitidoEm → DateTime?
-
final
- estadoCivil → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- naturalDe → String
-
final
- nomeCompleto → String
-
final
- numeroBilhete → String
-
final
- provinciaDe → String
-
final
- residencia → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sexo → Sexo
-
final
- validoAte → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited